require 'spec_helper'

describe Fetch do
  
  describe "url_for_date" do
    it 'should return a valid url for April 3rd 2014' do
      our_date = 'April 3rd 2014'
      result = Fetch.url_for_date(our_date)
      result.should == 'http://gd2.mlb.com/components/game/mlb/year_2014/month_04/day_03'
    end  

    it 'should return a valid milb url for 2014-04-24' do
      our_date = '2014-04-24'
      result = Fetch.url_for_date(our_date, :milb)
      result.should == 'http://gd2.mlb.com/components/game/milb/year_2014/month_04/day_24'
    end
  end

  describe "get_game_urls" do
    it 'should return list of games for April 3rd 2014' do

      list_of_games = Fetch.get_game_urls('April 3rd 2014')  
      
      list_of_games.should include({:game_id => "2014_04_03_seamlb_oakmlb_1", 
                                    :game_url => "http://gd2.mlb.com/components/game/mlb/year_2014/month_04/day_03/gid_2014_04_03_seamlb_oakmlb_1/game_events.xml"})
    end
  end

  describe "get_milb_schedule" do
    it 'should return list of home teams for April 23rd 2014' do
      list_of_games = Fetch.get_milb_schedule('April 23rd 2014')
      list_of_games.should include({:home_sname=>"Tampa", :home_fname=>"Tampa Yankees", :date=>"April 23, 2014"})
    end

    it 'should return list of home teams for 2014-04-24' do
      list_of_games = Fetch.get_milb_schedule('2014-04-24')
      list_of_games.should include({:home_sname=>"Stockton", :home_fname=>"Stockton Ports", :date=>"April 24, 2014"})
    end
  end

  describe "get_milb_home_teams" do
    it 'should have Trenton on July 11th 2014' do
      list_of_games = Fetch.get_game_home_teams('July 11th 2014', :milb_high)
      list_of_games.should include('Trenton Thunder')
    end
  end

  describe "get_mlb_home_teams" do
    it 'should have Philadelphia on April 6th 2015' do
      list_of_games = Fetch.get_game_home_teams('April 6th 2015', :mlb)
      list_of_games.should include('Philadelphia Phillies')
    end
  end

end
